@@ -6,7 +6,8 @@
 # Copyright (C) PyZMQ Developers
 # Distributed under the terms of the Modified BSD License.
 
-from zmq.eventloop import ioloop, zmqstream
+from tornado import ioloop
+from zmq.eventloop import zmqstream
 from .base import Authenticator
 
 
@@ -14,7 +15,7 @@ class IOLoopAuthenticator(Authenticator):
     """ZAP authentication for use in the tornado IOLoop"""
 
     def __init__(self, context=None, encoding='utf-8', log=None, io_loop=None):
-        super(IOLoopAuthenticator, self).__init__(context)
+        super(IOLoopAuthenticator, self).__init__(context, encoding, log)
         self.zap_stream = None
         self.io_loop = io_loop or ioloop.IOLoop.instance()
 
